/* Copyright 2007, 2012 Kevin Ryde.

   This file is part of x2gpm.

   x2gpm is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free
   Software Foundation; either version 3, or (at your option) any later
   version.

   x2gpm is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
   details.

   You should have received a copy of the GNU General Public License along
   with X2gpm; see the file COPYING.  Failing that, goto
   <http://www.gnu.org/licenses/>. */

#define _GNU_SOURCE
#include <assert.h>
#include <errno.h>
#include <fcntl.h>
#include <getopt.h>
#include <limits.h>
#include <locale.h>
#include <pwd.h>
#include <signal.h>
#include <stdarg.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>
#include <unistd.h>
#include <utmp.h>
#include <sys/types.h>
#include <sys/poll.h>

#undef WUNTRACED  /* avoid redefines from <linux/wait.h> */
#undef WNOHANG
#undef WSTOPPED
#undef WEXITED
#undef WCONTINUED
#include <linux/keyboard.h>  /* for KG_CTRL */
#include <linux/kd.h>        /* for KDGKBMODE */

#include <gpm.h>

#include <X11/Xatom.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#include <nl_types.h>
#include <langinfo.h>

char *
x11_strerror (Display *display, int code)
{
  static char buf[256];
  XGetErrorText (display, code, buf, sizeof (buf));
  return buf;
}

void
try (const char *locale)
{
  if (setlocale (LC_ALL, locale) == NULL)
    printf ("setlocale(\"%s\") failed\n", locale);
  else
    printf ("%s  %s  %d\n", locale, nl_langinfo(CODESET), XSupportsLocale ());
}

int
main (void)
{
  Display *display = XOpenDisplay (":0");
  puts (x11_strerror (display, XNoMemory));
  puts (x11_strerror (display, XLocaleNotSupported));
  puts (x11_strerror (display, XConverterNotFound));

  try ("xx_XX.fjdks");
  try ("ar_IN");
  try ("ar_YE");
  try ("be_BY");
  try ("de_DE");
  try ("el_GR");
  try ("en_AU");
  try ("en_IN");
  try ("en_US");
  try ("es_ES");
  try ("fr_CA");
  try ("fr_FR");
  try ("fr_FR.ISO-8859-15@euro");
  try ("ja_JP.EUC-JP");
  try ("ja_JP.UTF-8");
  try ("sl_SI");
  try ("th_TH");
  try ("vi_VN");
  try ("th_TH");
  return 0;
}
